Library for the nRF2401A Transceiver

Dependents:   nRF2401A_Hello_World nRF2401A_Wireless_Accelerometer_joypad nRF2401A_Gameduino_Invaders

Revision:
1:8c57f88ff574
Parent:
0:17cb4be1e37f
Child:
2:ca8602ee9e1d
--- a/nRF2401A.h	Fri Oct 04 16:14:49 2013 +0000
+++ b/nRF2401A.h	Fri Oct 04 16:23:58 2013 +0000
@@ -34,7 +34,7 @@
 #define   Thmin      5     /**< */
 #define   Tclk2data  1     /**< */
 
-/** Servo control class, based on a PwmOut
+/** nRF2401 Class 
  *
  * Example:
  * @code
@@ -140,7 +140,7 @@
         }
         
         /** Set the address of channel 1.
          * The channel address is a up to 40 bit number identifying the tranciever.
          * \param addr4 Bits 39-32 of the address.
          * \param addr4 Bits 31-24 of the address.
          * \param addr4 Bits 23-16 of the address.
@@ -183,7 +183,7 @@
         }
         
         /** Data rate settings.
          * Type covering the allowed settings for the tranciever data rate.
          */
         typedef enum
         {
@@ -191,7 +191,7 @@
             BIT_RATE_1MBITS = 0x1       /**< */
         } DATA_RATE_T;
         
         /** Set tranciever data rate.
          * Sets the data rate field to either 250 kbit/s or 1 Mbit/s data transfer rate.
          * \param mode The data rate of choise.
          * \return Reference to the invoked object (for chaining operations).
@@ -242,7 +242,7 @@
         nRF2401A& sendMsg(address_t addr, uint8_t addr_len, uint8_t *msg_buf, uint8_t msg_len);
         
         /** Register a receive action callback.
          * Attach a callback that will be called when the tranciever intercept a
          * message. This callback will be called in the context of an interrupt
          * routine and should act accordingly.
          * \param handler The callback, of type nRF2401_rx_handler_t.
@@ -268,9 +268,9 @@
         typedef enum 
         { 
             UNDEF,      /**< The start state. */
-            RX,         /**< The tranciever is in receive mode. */
-            TX,         /**< The tranciever is transmitting. */
-            STANDBY     /**< The tranciever goes into stanby mode. */
+            RX,         /**< The tranceiver is in receive mode. */
+            TX,         /**< The tranceiver is transmitting. */
+            STANDBY     /**< The tranceiver goes into stanby mode. */
         } STATE_T;
         
         STATE_T  _state;
@@ -331,7 +331,7 @@
          */
         void pushCtrl(uint8_t *buf, uint8_t n_bits, bool is_ctrl = true);
         
         /** Read a message from the tranciever.
          * Read until DR1 goes low.
          * \param buf Data buffer.
          * \return Number of bits read.
@@ -140,7 +140,7 @@
         
         /** Set the address of channel 1.
-         * The channel address is a up to 40 bit number identifying the tranciever.
+         * The channel address is a up to 40 bit number identifying the tranceiver.
          * \param addr4 Bits 39-32 of the address.
          * \param addr4 Bits 31-24 of the address.
@@ -183,7 +183,7 @@
         
         /** Data rate settings.
-         * Type covering the allowed settings for the tranciever data rate.
+         * Type covering the allowed settings for the tranceiver data rate.
          */
         typedef enum
@@ -191,7 +191,7 @@
         } DATA_RATE_T;
         
-        /** Set tranciever data rate.
+        /** Set tranceiver data rate.
          * Sets the data rate field to either 250 kbit/s or 1 Mbit/s data transfer rate.
          * \param mode The data rate of choise.
@@ -242,7 +242,7 @@
         
         /** Register a receive action callback.
-         * Attach a callback that will be called when the tranciever intercept a
+         * Attach a callback that will be called when the tranceiver intercept a
          * message. This callback will be called in the context of an interrupt
          * routine and should act accordingly.
@@ -331,7 +331,7 @@
         void pushCtrl(uint8_t *buf, uint8_t n_bits, bool is_ctrl = true);
         
-        /** Read a message from the tranciever.
+        /** Read a message from the tranceiver.
          * Read until DR1 goes low.
          * \param buf Data buffer.